==> nextcloud-29.0.10.tgz: nextcloud/apps/federation/l10n/ar.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "أُضيف إلى قائمة الخوادم غير الموثوقة",
    "Server is already in the list of trusted servers." : "الخادم موجود بالفعل في قائمة الخوادم الموثوقة.",
    "No server to federate with found" : "لم يُمكن إيجاد أي خادم للاتحاد معه",
    "Could not add server" : "تعذّرت إضافة الخادم",
    "Trusted servers" : "الخوادم الموثوقة",
    "Federation" : "الربط عبر السحابة الموحدة",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها. على سبيل المثال، سيتم استخدام هذا للإكمال التلقائي للحسابات الخارجية عند المشاركة عبر السحابة الموحدة federated sharing.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها. على سبيل المثال، سيتم استخدام هذا للإكمال التلقائي للحسابات الخارجية عند المشاركة الاتحادية. ليس من الضروري إضافة خادم كخادم موثوق به لإنشاء مشاركة السحابة الموحدة.",
    "+ Add trusted server" : "+ إضافة خادم موثوق",
    "Trusted server" : "خادم موثوق",
    "Add" : "إضافة",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين. على سبيل المثال: هذا يسمح بالاستكمال التلقائي لحسابات المستخدمين الخارجيين عبر المشاركات عبرالسحابة الموحدة.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين. على سبيل المثال: هذا يسمح بالاستكمال التلقائي لحسابات المستخدمين الخارجيين عبر المشاركات عبر السحابة الموحدة. و بالتالي، فلا  ضرورة لإضافة خادم لقائمة الخوادم الموثوقة من أجل إنشاء مُشاركات اتحاديّة."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");

==> nextcloud-30.0.5.tgz: nextcloud/apps/federation/l10n/ar.js <==
OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "أُضيف إلى قائمة الخوادم غير الموثوقة",
    "No server found with ID: %s" : "لايوجد أي خادوم بهذا الرقم: %s",
    "Could not remove server" : "تتعذّر إزالة الخادوم",
    "Server is already in the list of trusted servers." : "الخادم موجود بالفعل في قائمة الخوادم الموثوقة.",
    "No server to federate with found" : "لم يُمكن إيجاد أي خادم للاتحاد معه",
    "Could not add server" : "تعذّرت إضافة الخادم",
    "Trusted servers" : "الخوادم الموثوقة",
    "Federation" : "الربط عبر السحابة الموحدة",
    "Federation allows you to connect with other trusted servers to exchange the account directory." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها.",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها. على سبيل المثال، سيتم استخدام هذا للإكمال التلقائي للحسابات الخارجية عند المشاركة عبر السحابة الموحدة federated sharing.",
    "External documentation for Federated Cloud Sharing" : "التوثيق الخارجي لمشاركة السحابة الاتحادية",
    "Federation allows you to connect with other trusted servers to exchange the account directory. For example this will be used to auto-complete external accounts for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "يسمح لك الاتحاد بالاتصال بخوادم موثوقة أخرى لتبادل أدلة الحسابات معها. على سبيل المثال، سيتم استخدام هذا للإكمال التلقائي للحسابات الخارجية عند المشاركة الاتحادية. ليس من الضروري إضافة خادم كخادم موثوق به لإنشاء مشاركة السحابة الموحدة.",
    "Each server must validate the other. This process may require a few cron cycles." : "يجب على كل خادوم أن يُصادِق على الآخر. هذه العملية يمكن أن تستغرق عدة دورات من مهام الخلفية cron.",
    "+ Add trusted server" : "+ إضافة خادم موثوق",
    "Trusted server" : "خادم موثوق",
    "Add" : "إضافة",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين. على سبيل المثال: هذا يسمح بالاستكمال التلقائي لحسابات المستخدمين الخارجيين عبر المشاركات عبرالسحابة الموحدة.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "يُمكّنك الاتحاد من الاتصال بخوادم أخرى موثوقة لتبادل دليل المستخدمين. على سبيل المثال: هذا يسمح بالاستكمال التلقائي لحسابات المستخدمين الخارجيين عبر المشاركات عبر السحابة الموحدة. و بالتالي، فلا  ضرورة لإضافة خادم لقائمة الخوادم الموثوقة من أجل إنشاء مُشاركات اتحاديّة."
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
